import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:wolfflashlight/wolfflashlight.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  bool _hasFlashlight = false;
  Timer? timer;

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    bool hasFlashlight;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion =
          await Wolfflashlight.platformVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    try {
      hasFlashlight =
      await Wolfflashlight.hasFlashlight;
    } on PlatformException {
      hasFlashlight = false;
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
      _hasFlashlight = hasFlashlight;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
          appBar: AppBar(
            title: const Text('Plugin example app'),
          ),
          body: Center(
              child: Column(
                children: <Widget>[
                  Text(
                      'Running on: $_platformVersion\n flashlight is $_hasFlashlight'),
                  ElevatedButton(
                    child: Text('Turn on'),
                    onPressed: () => Wolfflashlight.lightOn(),
                  ),
                  ElevatedButton(
                    child: Text('Turn off'),
                    onPressed: () => Wolfflashlight.lightOff(),
                  ),
                  ElevatedButton(
                    child: Text('Turn WolfOn'),
                    onPressed: () =>
                    {
                      // Wolfflashlight.lightWolfOn()
                      timer =
                          Timer.periodic(Duration(milliseconds: 300), (timer) {
                            Wolfflashlight.lightFlash();
                          }),
                    }
                  ),
                  ElevatedButton(
                    child: Text('Turn Wolfoff'),
                    onPressed: () => timer?.cancel(),
                  ),
                ],
              ))
      ),
    );
  }
}
