import Flutter
import UIKit
import AVFoundation

public class SwiftWolfflashlightPlugin: NSObject, FlutterPlugin {
    
public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "wolfflashlight", binaryMessenger: registrar.messenger())
    let instance = SwiftWolfflashlightPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
}

public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
    case "getPlatformVersion":
        result("iOS " + UIDevice.current.systemVersion)
        break
    case "hasFlashlight":
            result(self.hasFlashlight())
            break
        case "lightOn":
            self.toggleFlash()
            result(nil)
            break
        case "lightOff":
            self.closeFlash()
            result(nil)
            break
        case "lightFlash":
            self.lightFlash()
            result(nil)
            break
        default:
            result(FlutterMethodNotImplemented)
            break
        }
  }
    
private func hasFlashlight () -> Bool{
     guard let device = AVCaptureDevice.default(for: AVMediaType.video) else { return false}
     return device.hasTorch
 }
 
private func toggleFlash() {
    guard let device = AVCaptureDevice.default(for: AVMediaType.video) else { return }
    guard device.hasFlash else { return }

    do {
        try device.lockForConfiguration()
        if(device.flashMode == .off){
            device.flashMode = .on
            device.torchMode = .on
            try device.setTorchModeOn(level: 1.0)
        }else if(device.flashMode == .on){
            device.flashMode = .off
            device.torchMode = .off
        }
        device.unlockForConfiguration()
    } catch {
        print(error)
    }
}

private func closeFlash() {
//    localTimer.invalidate()
    guard let device = AVCaptureDevice.default(for: AVMediaType.video) else { return }
    guard device.hasFlash else { return }

    do {
        try device.lockForConfiguration()
        if(device.flashMode == .on){
            device.flashMode = .off
            device.torchMode = .off
        }
        device.unlockForConfiguration()
    } catch {
        print(error)
    }
}

// private func lightWolfOn(){
//    localTimer.invalidate() // just in case this button is tapped multiple times
//    // start the timer
//    localTimer = Timer.scheduledTimer(timeInterval: 0.1, target: self, selector: #selector(timerAction), userInfo: nil, repeats: true)
// }
//
// @objc func timerAction() {
//    toggleFlash()
// }
    
//var flashSwitch = false
    
private func lightFlash(){
    DispatchQueue.global().async {
        guard let device = AVCaptureDevice.default(for: AVMediaType.video) else { return }
        guard device.hasTorch else { return }
        do {
            try device.lockForConfiguration()
//            while self.flashSwitch {
            device.flashMode = .on
            device.torchMode = .on
            try device.setTorchModeOn(level: AVCaptureDevice.maxAvailableTorchLevel)
            Thread.sleep(forTimeInterval: 0.010)
            device.flashMode = .off
            device.torchMode = .off
//            }
            device.unlockForConfiguration()
        } catch {
            print(error)
        }
    }
}
}
